* set your own default directory
* using FILE -> CHANGE WORKING DIRECTORY
* then browse to the folder you wish to use

use data_for_chapter_2.dta, clear
set more off

**********************************************
***** CHAPTER 2 RANDOM INTERCEPT MODELS ******
**********************************************

*for Table 2.1
regress z_read pos

su pos
return list
gen cen_pos = pos - r(mean)  

*for Table 2.2
regress z_read cen_pos
predict y

*for Figure 2.1
twoway (scatter z_read cen_pos) || (lfit z_read cen_pos), scheme(s1mono)
graph save figure2_1, asis replace
drop y

*for Table 2.3
xtreg z_read, i(region) mle

*for Table 2.4
mixed z_read || region:, stddev
estat icc

predict u0, reffects
predict u0se, reses
egen justone=tag(region)
sort u0
generate rank=sum(justone)
sort rank

*for Table 2.5
list region u0 u0se rank if justone==1

*for Figure 2.3
serrbar u0 u0se rank if justone==1, scale(1.96) yline(0) scheme(s1mono)
graph save figure2_3, asis replace
drop u0 u0se rank justone

*for Table 2.6
mixed z_read|| region:

egen schnum=count(schoolid), by(schoolid)
egen justone=tag(schoolid)

*for Table 2.7
su schnum if justone==1
drop schnum

*for Table 2.8
xtreg z_read, i(schoolid) mle

*for Table 2.9
mixed z_read || schoolid:
estat icc

predict u0, reffects
predict u0se, reses
sort u0
generate rank=sum(justone)
sort rank

*for Figure 2.4
serrbar u0 u0se rank if justone==1, scale(1.96) yline(0) scheme(s1mono)
graph save figure2_4, asis replace

*for Table 2.10
gsort -justone rank
list schoolid u0 u0se rank in 1/10
capture drop u0 u0se rank

*for Table 2.11
mixed z_read cen_pos || schoolid: 
estat icc

predict u0, reffects
predict u0se, reses
sort u0
generate rank=sum(justone)
sort rank

*for Table 2.12
gsort -justone -rank
list schoolid u0 u0se rank if justone==1&schoolid<11
capture drop u0 u0se rank justone

* for Figure 2.6
predict predscore, fitted
**created the predicted fitted values from the last model
egen justone=tag(schoolid cen_pos)
**selecting one observation per school and socioeconomic 
**status to minimize the number of data points
sort schoolid cen_pos
twoway connected predscore cen_pos if justone==1&schoolid<11, ///
	connect(ascending) msize(vtiny) xline(0) scheme(s1mono)
* need to add schoolid=3 box in edit function
graph save figure2_6, asis replace
drop justone

**creating a line graph demonstrating the different lines per school
drop predscore

* for Table 2.13
mixed z_read cen_pos female || schoolid:
estat icc

egen justone=tag(schoolid)
su schsize if justone==1

gen cen_size=schsize-r(mean)

* for Table 2.14
mixed z_read cen_pos female cen_size || schoolid:
estat icc

egen posmeans = mean(pos), by(schoolid)
gen grcen_pos = pos - posmeans

*for Table 2.15
mixed z_read grcen_pos female cen_size || schoolid:

su pcgirls if justone==1

gen cen_girls = pcgirls - r(mean)
gen femaleXcen_girls=female*cen_girls

*for Table 2.16
mixed z_read female cen_girls femaleXcen_girls || schoolid:
predict girls, fitted

*for Figure 2.7
twoway lfit girls cen_girls if female == 1 || ///
	lfit girls cen_girls if female ==0, ///
	legend(order(1 "girls" 2 "boys" )) ytitle(predicted reading) ///
	lpattern(solid) lpattern(dash) ///
	lcolor(black) lcolor(black) scheme(s1mono)
graph save figure2_7, asis replace

* other way of doing Table 2.16 and Figure 2.7
mixed z_read  female##c.cen_girls || schoolid:
quietly margins, at(cen_girls=(-0.5(0.1)0.5)) over(female)
marginsplot

su stratio if justone==1
gen cen_ratio=stratio - r(mean)

*for Table 2.17
mixed z_read c.cen_pos##c.cen_ratio || schoolid: if female==0

capture drop tertiles
xtile tertiles=cen_ratio if justone==1, nq(3)
gsort schoolid -justone
by schoolid: replace tertiles=tertiles[_n-1] if tertiles==.
ta tertiles if justone==1
ta tertiles

*for Figure 2.8
quietly margins, at(cen_pos=(-20(5)20)) over(tertiles)
marginsplot, noci legend(order(1 "Low TSR school" 2 "Med TSR school" 3 "High TSR school" )) ///
	plot1opts (msymbol(O) lpattern(solid) lcolor(black)) ///
	plot2opts (msymbol(D) lpattern(solid) lcolor(black)) ///
	plot3opts (msymbol(T) lpattern(solid) lcolor(black)) scheme(s1mono)
graph save figure2_8, asis replace

/*
* manual way of doing Figure 2.8
gen cen_posXcen_ratio=cen_pos*cen_ratio
mixed z_read cen_pos cen_ratio cen_posXcen_ratio || schoolid: if female==0
capture drop y
predict y, xb
twoway 	lfit y cen_pos if tertile==1 || ///
		lfit y cen_pos if tertile==2 || ///
		lfit y cen_pos if tertile==3
*/

capture drop justone tertiles

quietly xtmixed z_read || schoolid:
estat ic
xtmrho
estimates store null

quietly xtmixed z_read female || schoolid: 
estat ic
xtmrho
estimates store model1

quietly xtmixed z_read female cen_pos || schoolid: 
estat ic
xtmrho
estimates store model2

quietly xtmixed z_read female cen_pos cen_size || schoolid: 
estat ic
xtmrho
estimates store model3
 
*for Table 2.18 - we deal with the esttab command in Chapter 4
esttab null model1 model2 model3 , se aic bic scalars(ll rho1)

lrtest model1 null
lrtest model2 model1
lrtest model3 model2

*for Table 2.19 Model 1
estimates restore null 
scalar a=e(var_u1)
scalar b=e(var_e)

estimates restore model1
scalar c=e(var_u1)
scalar d=e(var_e)

scalar x=[[scalar(a)+scalar(b)] - [scalar(d)+scalar(c)]]/[scalar(a)+scalar(b)]

*for Table 2.19 Model 2
estimates restore model2
scalar c=e(var_u1)
scalar d= e(var_e)

scalar y = [[scalar(a)+scalar(b)] - [scalar(d)+scalar(c)]]/[scalar(a)+scalar(b)]

*for Table 2.19 Model 3
estimates restore model3
scalar c=e(var_u1)
scalar d= e(var_e)

scalar z=[[scalar(a)+scalar(b)] - [scalar(d)+scalar(c)]]/[scalar(a)+scalar(b)]

*for Table 2.19
di "Model 1 Overall R2 is: " [scalar(x)] ///
	_n "Model 2 Overall R2 is: " [scalar(y)] ///
	_n "Model 3 Overall R2 is: " [scalar(z)]

* Extra figures on Model 3 for text and Table 2.20
di "Model 3 Level 1 R2 is: " [scalar(b)-scalar(d)]/scalar(d)
di "Model 3 Level 2 R2 is: " [scalar(a)-scalar(c)] /scalar(c)

* for Table 2.20
capture ssc install mlt 
quietly xtmixed z_read female cen_pos cen_size || schoolid: 
mltrsq


mixed z_read female cen_pos cen_size || schoolid:
*Level 1 residuals
predict L1_resid, residuals 
*Level 2 residuals
predict L2_resid, reffects 

*for Figure 2.9
histogram L1_resid, normal title("Histogram of Level 1 Residuals") scheme(s1mono)
graph save h1, replace 
histogram L2_resid, normal title("Histogram of Level 2 residuals") scheme(s1mono)
graph save h2, replace 
qnorm L1_resid, title("Qnorm Plot of Level 1 Residuals") scheme(s1mono)
graph save q1, replace 
qnorm L2_resid, title("Qnorm Plot Level 2 Residuals") scheme(s1mono)
graph save q2, replace 

*combine all graphs into one output
graph combine h1.gph h2.gph q1.gph q2.gph, scheme(s1mono)
graph save figure2_9, asis replace


