* set your own default directory
* using FILE -> CHANGE WORKING DIRECTORY
* then browse to the folder you wish to use

use data_for_chapter_3.dta, clear
set more off

**********************************************
**** CHAPTER 3 RANDOM COEFFICIENT MODELS *****
**********************************************

statsby intercept=_b[_cons] coeff=_b[cen_pos], ///
	by(schoolid) saving(ols, replace): reg z_read cen_pos

use "ols",clear
su intercept coef
sort coeff
list schoolid intercept coeff in 1/5
list schoolid intercept coeff in -5/-1 
histogram coeff

use "data_for_chapter_3",clear
set more off

merge m:1 schoolid using "ols"

gen yhat = intercept+(coeff*cen_pos)
sort schoolid cen_pos

*for Figure 3.2
line yhat cen_pos if schoolid<13, connect(ascending) xline(0) yline(0) scheme(s1mono)
graph save figure3_2, asis replace
drop _merge yhat coeff intercept

*for Table 3.1
mixed z_read cen_pos || schoolid: cen_pos, ///
	stddev covariance(unstructured) nolog
estat recovariance
estimates store rc

quietly mixed z_read cen_pos || schoolid:, nolog 
estimates store ri
lrtest rc ri

*Models using ESCS

egen meanescs=mean(escs)
gen cen_escs=escs-meanescs
su cen_escs
histogram cen_escs
drop meanescs

*for Table 3.2
mixed z_read cen_escs || schoolid:, stddev nolog
estimates store ri

*for Table 3.3
mixed z_read cen_escs || schoolid: cen_escs, stddev cov(un) nolog
estimates store rc

lrtest rc ri

*for Figure 3.3
*first, generate predicted random effects for the slope and intercept
predict u1 u0, reffects
*second, pick one observation per school
egen pickone=tag(schoolid)
*third, create a scatterplot with each dot representing a school
scatter u1 u0 if pickone==1, yline(0) xline(0) scheme(s1mono)
graph save figure3_3, asis replace

gen intercept=-0.015+u0 if pickone==1
gen coeff=0.3548+u1 if pickone==1
drop u1 u0

*for Table 3.4
su intercept coeff if pickone==1

*for Figure 3.4
*need to add Q1 etc manually
scatter coeff intercept, msymbol(x) msize(large) ///
	yline(0.3548) xline(-0.015) scheme(s1mono)
graph save figure3_4, asis replace

*for Figure 3.5
predict predscore, fitted
line predscore cen_escs, connect(ascending) ///
 title(Random Coefficient Regression Lines) scheme(s1mono)
graph save rc, replace
drop predscore

***for comparative purposes, these are the individual OLS regressions 
***plotted together in one graph

statsby sa=_b[_cons] sb=_b[cen_escs], by(schoolid) ///
	saving(ols, replace): regress z_read cen_escs  
sort schoolid
merge m:1 schoolid using ols
gen yhat = sa+sb*cen_escs
sort schoolid cen_escs
line yhat cen_escs, connect(ascending) ///
	title(OLS Regression Lines) scheme(s1mono)
graph save ols, replace
drop _merge yhat coeff intercept

graph combine rc.gph ols.gph, ycommon scheme(s1mono)
graph save figure3_5, asis replace

*ri and rc models for variances
mixed z_read cen_escs || schoolid:
mixed z_read cen_escs || schoolid: cen_escs , ///
	cov(un)

*for Figure 3.9
twoway function 0.1657 + [2*-0.0226*x] + [0.0195*x^2], ///
	range(-4 2) xtitle(cen_escs) ///
	ytitle(Estimates of between-school variance) ///
	scheme(s1mono)
graph save figure3_9, asis replace

*for Table 3.5
quietly: mixed z_read female || schoolid:
estimates store ri
mixed z_read female || schoolid:  female, cov(un) nolog
estimates store rc
lrtest rc ri

estat recov, corr

predict u1 u0, reffects
su u1 u0 if pickone==1

*if you want to see the same graphs (except OLS)
scatter u1 u0 if pickone==1, yline(0) xline(0) scheme(s1mono)
predict predscore, fitted
line predscore female, connect(ascending) ///
	title(Random Coefficient Regression Lines) scheme(s1mono)

drop u1 u0 predscore

quietly mixed z_read cen_escs female || ///
	schoolid: cen_escs, cov(un)
estimates store rc1
quietly mixed z_read cen_escs female || ///
	schoolid: cen_escs  female, cov(un)
estimates store rc2
lrtest rc1 rc2

*for Table 3.6
estimates replay rc2
estat recov, corr 

predict u1 u2 u0, reffects

*for Figure 3.10
scatter u1 u2 if pickone==1, yline(0) xline(0) scheme(s1mono)
graph save figure3_10, asis replace
drop u1 u2 u0

*for Table 3.7
mixed z_read cen_pos female || schoolid: female, ///
	stddev cov(un) nolog
estimates store model1

gen cen_size100=cen_size/100

*for Table 3.8	
mixed z_read cen_pos female cen_size100 || ///
	schoolid:  female, stddev cov(un) nolog
estimates store model2
lrtest model1 model2

mixed z_read cen_escs female || schoolid: cen_escs  female, cov(un) var
predict resid, residuals
predict u1 u2 u0, reffects
histogram resid, normal title("L1 residuals") scheme(s1mono)
graph save a1, replace
histogram u0, normal title("L2 residuals") scheme(s1mono)
graph save a2, replace
histogram u1, normal title("RC1 escs") scheme(s1mono)
graph save a3, replace
histogram u2, normal title("RC2 female") scheme(s1mono)
graph save a4, replace
qnorm resid, title("L1 Residuals") scheme(s1mono)
graph save b1, replace
qnorm u0, title("L2 Residuals") scheme(s1mono)
graph save b2, replace
qnorm u1, title("RC1 escs") scheme(s1mono)
graph save b3, replace
qnorm u2, title("RC2 female") scheme(s1mono)
graph save b4, replace

*for Figure 3.11
graph combine a1.gph a2.gph a3.gph a4.gph b1.gph b2.gph b3.gph b4.gph, ///
	r(2) scheme(s1mono)
graph save figure3_11, asis replace

*outliers

list schoolid if u0 < -1.5 & pickone==1
list schoolid if u1 > 0.3 & pickone==1

* need to use xtmixed so xtmrho works
xtmixed z_read cen_escs female || schoolid: cen_escs  female, cov(un) var
xtmrho
estimates store a1

xtmixed z_read cen_escs female || schoolid: cen_escs  female if schoolid!=132, ///
	cov(un) var
xtmrho
estimates store a2

*for Table 3.9
esttab a1 a2 using table3_9.rtf,replace ///
	se se(3) b(3) ///
	not nodepvars nostar nonumbers ///
	scalars(rho1 ll) ///
	mtitles("All schools" "Exc. No.132") ///
	coeflabels(cen_escs ESCS female Female _cons Constant) ///
	transform(ln*: exp(2*@) 2*exp(2*@) at*: tanh(@) (1-tanh(@)^2)) ///
	eqlabels(, none)

*model building

* Step 1
mixed z_read || schoolid:, nolog   
* see Table 2.9 
est store null

* Step 2(a)
mixed z_read cen_pos || schoolid:, nolog   
* see Table 2.11
est store ri_pos
lrtest ri_pos null

*Step 2(b)
mixed z_read female || schoolid:, nolog
est store ri_female
lrtest ri_female null

* Step 3(a)
mixed z_read cen_pos || schoolid: cen_pos, cov(un) nolog   
* see Table 3.1
est store rc_pos
lrtest rc_pos ri_pos

* Step 3(b)
mixed z_read female || schoolid: female, cov(un) nolog   
* see Table 3.5
est store rc_female
lrtest rc_female ri_female

* Step 4(a)
mixed z_read cen_pos female || schoolid:, nolog 
est store mod_a

* Step 4(b)
mixed z_read cen_pos female || schoolid: female, cov(un) nolog   
* see Table 3.7 
est store mod_b
lrtest mod_b mod_a

* Step 4(c)
mixed z_read cen_pos female cen_size100 || ///
	schoolid: female, cov(un) nolog   
* see Table 3.8
est store mod_c
lrtest mod_c mod_b


*three level model taster

*Table 3.10 three-level null model
mixed z_read || region: || schoolid: , nolog
est store null3
lrtest null3 null

tabstat schoolid if pickone==1, by(region) stat(n)

*Table 3.11 three-level RI model
mixed z_read cen_pos female cen_size100 || ///
	region: || ///
	schoolid: , nolog nogroup
est store ri3
lrtest ri3 null3

*Table 3.12 three-level RC model (1)
mixed z_read cen_pos female cen_size100 || ///
	region: || ///
	schoolid: female, cov(un) stddev nolog nogroup
est store rc3_1
lrtest rc3_1 ri3

*Table 3.13 three-level RC model (2)
mixed z_read cen_pos female cen_size100 || ///
	region: cen_size100, cov(un) || ///
	schoolid: female, cov(un) stddev nolog nogroup
est store rc3_2
lrtest rc3_2 rc3_1

xtile hiread=z_read,nq(10)
recode hiread 1/9=0 10=1

melogit hiread cen_pos female || schoolid:, or

* Table 3.14
melogit hiread cen_pos female || schoolid: female, or 

* Table 3.15
mixed z_read female cen_pos cen_size || schoolid: 
estimates store unweighted

mixed z_read female cen_pos cen_size || ///
	schoolid: ,pweight(w_fschwt) pwscale(size)
estimates store weighted

esttab unweighted weighted, se b(4) se(4) ///
	transform(ln*: exp(2*@) 2*exp(2*@)) ///
	eqlabels("" "var(Constant)" "var(Residual)") ///
	mtitles("Unweighted" "Weighted")


