* set your own default directory
* using FILE -> CHANGE WORKING DIRECTORY
* then browse to the folder you wish to use

use data_for_chapter_4.dta, clear
set more off

**********************************************
**** CHAPTER 4 PRESENTING RESULTS *****
**********************************************

** ssc install estout (if not already installed)

gen schsize100=schsize/100
lab var schsize100 "School size/100 students"

mixed z_read || schoolid:
estat icc
estadd scalar icc = r(icc2)
estimates store null

mixed z_read female || schoolid:
estat icc
estadd scalar icc = r(icc2)
estimates store model2

mixed z_read female pos pcgirls schsize100 || schoolid:
estat icc
estadd scalar icc = r(icc2)
estimates store model3

esttab null model2 model3, se aic bic scalars(icc ll df_m) ///
transform(ln*: exp(@)^2 exp(@)^2) ///
eqlabels("" "var(Constant)" "var(Residual)" )

**add variable labels to table
esttab null model2 model3, label se aic bic scalars(icc ll df_m) ///
	transform(ln*: exp(@)^2 exp(@)^2) ///
	eqlabels("" "var(Constant)" "var(Residual)" )

**export output to rtf file
esttab null model2 model3, label se aic bic scalars(icc ll df_m) ///
	transform(ln*: exp(@)^2 exp(@)^2) ///
	eqlabels("" "var(Constant)" "var(Residual)" ), ///
	using Chapter4_table1.rtf, replace

**export to a doc file
esttab null model2 model3, label se aic bic scalars(icc ll df_m) ///
	transform(ln*: exp(@)^2 exp(@)^2) ///
	eqlabels("" "var(Constant)" "var(Residual)" ), ///
	using Chapter4_table1.doc, replace

	
***random coefficient models

eststo drop *

mixed z_read || schoolid:
estat icc
estadd scalar icc = r(icc2)
estimates store null

mixed z_read female || schoolid:
estat icc
estadd scalar icc = r(icc2)
estimates store model2

mixed z_read female pos escs schsize100 || schoolid:
estat icc
estadd scalar icc = r(icc2)
estimates store model3

mixed z_read female pos escs schsize100 || schoolid: escs, cov(uns) nolog 
estat icc
estadd scalar icc = r(icc2)
estimates store model4

esttab null model*, not transform(ln*: exp(@)^2 exp(@)^2)

***moving variance parameters in output to correct positions
esttab null model2 model3 model4, not transform(#*: exp(@)^2 exp(@)^2) /// 
	equations(2:2:2:3, 3:3:3:5, .:.:.:2, .:.:.:4) 
	
**making nicer ouput
esttab null model2 model3 model4 using Chapter4_table2.doc, replace ///
	wide not scalars(icc ll) transform(#*: exp(@)^2 exp(@)^2) ///
	equations(2:2:2:3, 3:3:3:4, .:.:.:2, .:.:.:4) stardrop(#*:)

	
***graphing interactions

** Level 1 * Level 1 interaction
mixed z_read female##c.pos escs schsize100 || schoolid:

**create variable measuring quartiles of pos
xtile quartpos=pos, nq(4)
ta quartpos

mixed z_read female##quartpos escs  schsize100 || schoolid: 
margins female#quartpos

*Figure 4.1
marginsplot, recast(line) recastci(rarea)  xdimension(quartpos) scheme(s1mono)
graph save figure4_1, asis replace

**cross level interaction****

mixed z_read female##c.schsize100 escs pos || schoolid: 

margins, at(schsize100=(1(5)26)) over(female)

*Figure 4.2
marginsplot, scheme(s1mono)
graph save figure4_2, asis replace

mixed z_read female##c.schsize100 escs pos || schoolid: 
estimates store xlevelinteraction
estat icc
estadd scalar icc = r(icc2)

esttab xlevelinteraction using Chapter4_table3.doc, replace ///
	transform(ln*: exp(@)^2 exp(@)^2) ///
	wide se scalars(icc ll) stardrop(*:)

